@@ -557,7 +557,7 @@ _wnck_get_utf8_list (Window   xwindow,
    * property is nul-separated
    */
   i = 0;
-  n_strings = 1;
+  n_strings = 0;
   while (i < nitems)
     {
       if (val[i] == '\0')
@@ -565,6 +565,9 @@ _wnck_get_utf8_list (Window   xwindow,
       ++i;
     }
 
+  if (val[nitems - 1] != '\0')
+    ++n_strings;
+
   /* we're guaranteed that val has a nul on the end
    * by XGetWindowProperty
    */
@@ -826,7 +829,8 @@ _wnck_deiconify (Window xwindow)
 
 void
 _wnck_close (Screen *screen,
-	     Window  xwindow)
+	     Window  xwindow,
+	     Time    timestamp)
 {
   XEvent xev;
   
@@ -837,7 +841,7 @@ _wnck_close (Screen *screen,
   xev.xclient.window = xwindow;
   xev.xclient.message_type = _wnck_atom_get ("_NET_CLOSE_WINDOW");
   xev.xclient.format = 32;
-  xev.xclient.data.l[0] = 0;
+  xev.xclient.data.l[0] = timestamp;
   xev.xclient.data.l[1] = 0;
   xev.xclient.data.l[2] = 0;
 
@@ -1235,7 +1239,7 @@ _wnck_select_input (Window xwindow,
  */
 static gboolean
 find_largest_sizes (gulong *data,
-                    int     nitems,
+                    gulong  nitems,
                     int    *width,
                     int    *height)
 {
@@ -1270,7 +1274,7 @@ find_largest_sizes (gulong *data,
 
 static gboolean
 find_best_size (gulong  *data,
-                int      nitems,
+                gulong   nitems,
                 int      ideal_width,
                 int      ideal_height,
                 int     *width,
